
### <a name="manual"></a> Pre block

Display content as preformatted text.

| Key       |      Description      | Default |
|:----------|:--------------------- |:----- |
| type      |  pre                 |  
| content      |  text to be rendered as pre      |  




Example:
```YAML
- type     : pre
  content  : |
    +----------+--------+
    | Name     | Score  |
    +----------+--------+
    | Alice    |  88    |
    | Bob      |  92    |
    +----------+--------+
```

Back to [Documentation](../../../README.md#block_structure)
- 
